# Beta notes

Release 0.2.0 of redis-cluster is a Beta release.

Before using this lib please read the documentation and understand the major differences and problems that exists with redis clustering. The following documents is best to read.

- [Command differences](docs/Commands.md)
- [Limitations and differences](docs/Limits_and_differences.md)

It is recommended to test this lib in real world scenarios to find problems and areas to improve for next release.

It is NOT recommended to run this lib in production.

If you find any bugs or have ideas for improvment please open a ticket at https://github.com/Grokzen/redis-py-cluster
